# Copyright 2013 Jeffrey Kegler
# This file is part of Marpa::R2.  Marpa::R2 is free software: you can
# redistribute it and/or modify it under the terms of the GNU Lesser
# General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later version.
#
# Marpa::R2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser
# General Public License along with Marpa::R2.  If not, see
# http://www.gnu.org/licenses/.

package Marpa::R2::MetaG;

use 5.010;
use strict;
use warnings;

use vars qw($VERSION $STRING_VERSION);
$VERSION        = '2.047_009';
$STRING_VERSION = $VERSION;
## no critic(BuiltinFunctions::ProhibitStringyEval)
$VERSION = eval $VERSION;
## use critic

package Marpa::R2::Internal::MetaG;

use English qw( -no_match_vars );

sub hashed_grammar {
    my $hashed_metag;

## no critic(RegularExpressions::RequireDotMatchAnything)
## no critic(RegularExpressions::RequireExtendedFormatting)
## no critic(RegularExpressions::RequireLineBoundaryMatching)
## no critic(RegularExpressions::ProhibitEscapedMetacharacters)
## no critic(RegularExpressions::ProhibitComplexRegexes)

## The code after this line was automatically generated by sl_to_hash.pl
## Date: Sun Mar  3 19:50:05 2013
$hashed_metag = {
                  'character_classes' => {
                                           '[[\']]' => qr/(?msx-i:['])/,
                                           '[[,]]' => qr/(?msx-i:[,])/,
                                           '[[01]]' => qr/(?msx-i:[01])/,
                                           '[[\\#]]' => qr/(?msx-i:[\#])/,
                                           '[[\\(]]' => qr/(?msx-i:[\(])/,
                                           '[[\\)]]' => qr/(?msx-i:[\)])/,
                                           '[[\\*]]' => qr/(?msx-i:[\*])/,
                                           '[[\\+]]' => qr/(?msx-i:[\+])/,
                                           '[[\\:]]' => qr/(?msx-i:[\:])/,
                                           '[[\\;]]' => qr/(?msx-i:[\;])/,
                                           '[[\\<]]' => qr/(?msx-i:[\<])/,
                                           '[[\\=]]' => qr/(?msx-i:[\=])/,
                                           '[[\\>]]' => qr/(?msx-i:[\>])/,
                                           '[[\\[]]' => qr/(?msx-i:[\[])/,
                                           '[[\\\\]]' => qr/(?msx-i:[\\])/,
                                           '[[\\]]]' => qr/(?msx-i:[\]])/,
                                           '[[\\s\\w]]' => qr/(?msx-i:[\s\w])/,
                                           '[[\\s]]' => qr/(?msx-i:[\s])/,
                                           '[[\\w]]' => qr/(?msx-i:[\w])/,
                                           '[[\\x{A}\\x{B}\\x{C}\\x{D}\\x{2028}\\x{2029}]]' => qr/(?msx-i:[\x{A}\x{B}\x{C}\x{D}\x{2028}\x{2029}])/,
                                           '[[\\|]]' => qr/(?msx-i:[\|])/,
                                           '[[\\~]]' => qr/(?msx-i:[\~])/,
                                           '[[^\'\\x{0A}\\x{0B}\\x{0C}\\x{0D}\\x{0085}\\x{2028}\\x{2029}]]' => qr/(?msx-i:[^'\x{0A}\x{0B}\x{0C}\x{0D}\x{0085}\x{2028}\x{2029}])/,
                                           '[[^:]]' => qr/(?msx-i:[^:])/,
                                           '[[^\\x{5d}\\x{0A}\\x{0B}\\x{0C}\\x{0D}\\x{0085}\\x{2028}\\x{2029}]]' => qr/(?msx-i:[^\x{5d}\x{0A}\x{0B}\x{0C}\x{0D}\x{0085}\x{2028}\x{2029}])/,
                                           '[[^\\x{A}\\x{B}\\x{C}\\x{D}\\x{2028}\\x{2029}]]' => qr/(?msx-i:[^\x{A}\x{B}\x{C}\x{D}\x{2028}\x{2029}])/,
                                           '[[a-zA-Z]]' => qr/(?msx-i:[a-zA-Z])/,
                                           '[[a]]' => qr/(?msx-i:[a])/,
                                           '[[b]]' => qr/(?msx-i:[b])/,
                                           '[[c]]' => qr/(?msx-i:[c])/,
                                           '[[d]]' => qr/(?msx-i:[d])/,
                                           '[[e]]' => qr/(?msx-i:[e])/,
                                           '[[f]]' => qr/(?msx-i:[f])/,
                                           '[[g]]' => qr/(?msx-i:[g])/,
                                           '[[h]]' => qr/(?msx-i:[h])/,
                                           '[[i]]' => qr/(?msx-i:[i])/,
                                           '[[l]]' => qr/(?msx-i:[l])/,
                                           '[[m]]' => qr/(?msx-i:[m])/,
                                           '[[n]]' => qr/(?msx-i:[n])/,
                                           '[[o]]' => qr/(?msx-i:[o])/,
                                           '[[p]]' => qr/(?msx-i:[p])/,
                                           '[[r]]' => qr/(?msx-i:[r])/,
                                           '[[s]]' => qr/(?msx-i:[s])/,
                                           '[[t]]' => qr/(?msx-i:[t])/,
                                           '[[u]]' => qr/(?msx-i:[u])/,
                                           '[[v]]' => qr/(?msx-i:[v])/,
                                           '[[x]]' => qr/(?msx-i:[x])/
                                         },
                  'g0_rules' => [
                                  {
                                    'lhs' => '[:discard]',
                                    'rhs' => [
                                               'hash comment'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:discard]',
                                    'rhs' => [
                                               'whitespace'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[:discard]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-0]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-10]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-11]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-12]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-13]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-14]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-15]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-16]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-17]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-18]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-19]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-1]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-20]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-21]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-22]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-23]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-24]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-25]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-26]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-27]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-2]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-3]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-4]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-5]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-6]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-7]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-8]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               '[Lex-9]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'array descriptor'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'bare name'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'boolean'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'bracketed name'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'character class'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'op declare bnf'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'op declare match'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'op equal priority'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'op loosen'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'reserved action name'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'reserved blessing name'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'single quoted string'
                                             ]
                                  },
                                  {
                                    'lhs' => '[:start_lex]',
                                    'rhs' => [
                                               'standard name'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-0]',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\;]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-10]',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-11]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[l]]',
                                               '[[e]]',
                                               '[[f]]',
                                               '[[t]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-12]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[a]]',
                                               '[[s]]',
                                               '[[s]]',
                                               '[[o]]',
                                               '[[c]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-13]',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-14]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[r]]',
                                               '[[i]]',
                                               '[[g]]',
                                               '[[h]]',
                                               '[[t]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-15]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[a]]',
                                               '[[s]]',
                                               '[[s]]',
                                               '[[o]]',
                                               '[[c]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-16]',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-17]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[g]]',
                                               '[[r]]',
                                               '[[o]]',
                                               '[[u]]',
                                               '[[p]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-18]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[s]]',
                                               '[[e]]',
                                               '[[p]]',
                                               '[[a]]',
                                               '[[r]]',
                                               '[[a]]',
                                               '[[t]]',
                                               '[[o]]',
                                               '[[r]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-19]',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-1]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\:]]',
                                               '[[s]]',
                                               '[[t]]',
                                               '[[a]]',
                                               '[[r]]',
                                               '[[t]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-20]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[p]]',
                                               '[[r]]',
                                               '[[o]]',
                                               '[[p]]',
                                               '[[e]]',
                                               '[[r]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-21]',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-22]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[b]]',
                                               '[[l]]',
                                               '[[e]]',
                                               '[[s]]',
                                               '[[s]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-23]',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-24]',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\(]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-25]',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\)]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-26]',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\*]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-27]',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\+]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-2]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\:]]',
                                               '[[d]]',
                                               '[[e]]',
                                               '[[f]]',
                                               '[[a]]',
                                               '[[u]]',
                                               '[[l]]',
                                               '[[t]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-3]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[l]]',
                                               '[[e]]',
                                               '[[x]]',
                                               '[[e]]',
                                               '[[m]]',
                                               '[[e]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-4]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[d]]',
                                               '[[e]]',
                                               '[[f]]',
                                               '[[a]]',
                                               '[[u]]',
                                               '[[l]]',
                                               '[[t]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-5]',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-6]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\:]]',
                                               '[[d]]',
                                               '[[i]]',
                                               '[[s]]',
                                               '[[c]]',
                                               '[[a]]',
                                               '[[r]]',
                                               '[[d]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-7]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[a]]',
                                               '[[c]]',
                                               '[[t]]',
                                               '[[i]]',
                                               '[[o]]',
                                               '[[n]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-8]',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\=]]',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => '[Lex-9]',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[a]]',
                                               '[[s]]',
                                               '[[s]]',
                                               '[[o]]',
                                               '[[c]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'array descriptor',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\[]]',
                                               'result item descriptor list',
                                               '[[\\]]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'bare name',
                                    'min' => 1,
                                    'rhs' => [
                                               '[[\\w]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'boolean',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[01]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'bracketed name',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\<]]',
                                               'bracketed name string',
                                               '[[\\>]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'bracketed name string',
                                    'min' => 1,
                                    'rhs' => [
                                               '[[\\s\\w]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'cc element',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'escaped cc character'
                                             ]
                                  },
                                  {
                                    'lhs' => 'cc element',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'posix char class'
                                             ]
                                  },
                                  {
                                    'lhs' => 'cc element',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'safe cc character'
                                             ]
                                  },
                                  {
                                    'lhs' => 'cc elements',
                                    'min' => 1,
                                    'rhs' => [
                                               'cc element'
                                             ]
                                  },
                                  {
                                    'lhs' => 'character class',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\[]]',
                                               'cc elements',
                                               '[[\\]]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'colon free text',
                                    'min' => 1,
                                    'rhs' => [
                                               '[[^:]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'escaped cc character',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\\\]]',
                                               'horizontal character'
                                             ]
                                  },
                                  {
                                    'lhs' => 'hash comment',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'terminated hash comment'
                                             ]
                                  },
                                  {
                                    'lhs' => 'hash comment',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'unterminated final hash comment'
                                             ]
                                  },
                                  {
                                    'lhs' => 'hash comment body',
                                    'min' => 0,
                                    'rhs' => [
                                               'hash comment char'
                                             ]
                                  },
                                  {
                                    'lhs' => 'hash comment char',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[^\\x{A}\\x{B}\\x{C}\\x{D}\\x{2028}\\x{2029}]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'horizontal character',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[^\\x{A}\\x{B}\\x{C}\\x{D}\\x{2028}\\x{2029}]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'one or more word characters',
                                    'min' => 1,
                                    'rhs' => [
                                               '[[\\w]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'op declare bnf',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\:]]',
                                               '[[\\:]]',
                                               '[[\\=]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'op declare match',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\~]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'op equal priority',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\|]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'op loosen',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\|]]',
                                               '[[\\|]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'posix char class',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\[]]',
                                               '[[\\:]]',
                                               'colon free text',
                                               '[[\\:]]',
                                               '[[\\]]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'reserved action name',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\:]]',
                                               '[[\\:]]',
                                               'one or more word characters'
                                             ]
                                  },
                                  {
                                    'lhs' => 'reserved blessing name',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\:]]',
                                               '[[\\:]]',
                                               'one or more word characters'
                                             ]
                                  },
                                  {
                                    'lhs' => 'result item descriptor',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[r]]',
                                               '[[a]]',
                                               '[[n]]',
                                               '[[g]]',
                                               '[[e]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'result item descriptor',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[v]]',
                                               '[[a]]',
                                               '[[l]]',
                                               '[[u]]',
                                               '[[e]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'result item descriptor',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[v]]',
                                               '[[a]]',
                                               '[[l]]',
                                               '[[u]]',
                                               '[[e]]',
                                               '[[s]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'result item descriptor list',
                                    'min' => 0,
                                    'rhs' => [
                                               'result item descriptor'
                                             ],
                                    'separator' => '[[,]]'
                                  },
                                  {
                                    'lhs' => 'safe cc character',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[^\\x{5d}\\x{0A}\\x{0B}\\x{0C}\\x{0D}\\x{0085}\\x{2028}\\x{2029}]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'single quoted string',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\']]',
                                               'string without single quote or vertical space',
                                               '[[\']]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'standard name',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[a-zA-Z]]',
                                               'zero or more word characters'
                                             ]
                                  },
                                  {
                                    'lhs' => 'string without single quote or vertical space',
                                    'min' => 1,
                                    'rhs' => [
                                               '[[^\'\\x{0A}\\x{0B}\\x{0C}\\x{0D}\\x{0085}\\x{2028}\\x{2029}]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'terminated hash comment',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\#]]',
                                               'hash comment body',
                                               'vertical space char'
                                             ]
                                  },
                                  {
                                    'lhs' => 'unterminated final hash comment',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\#]]',
                                               'hash comment body'
                                             ]
                                  },
                                  {
                                    'lhs' => 'vertical space char',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[[\\x{A}\\x{B}\\x{C}\\x{D}\\x{2028}\\x{2029}]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'whitespace',
                                    'min' => 1,
                                    'rhs' => [
                                               '[[\\s]]'
                                             ]
                                  },
                                  {
                                    'lhs' => 'zero or more word characters',
                                    'min' => 0,
                                    'rhs' => [
                                               '[[\\w]]'
                                             ]
                                  }
                                ],
                  'g1_rules' => [
                                  {
                                    'action' => '::first',
                                    'lhs' => '[:start]',
                                    'rhs' => [
                                               'statements'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'action',
                                    'lhs' => 'action',
                                    'mask' => [
                                                0,
                                                0,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-7]',
                                               '[Lex-8]',
                                               'action name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'action_name',
                                    'lhs' => 'action name',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'array descriptor'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'action_name',
                                    'lhs' => 'action name',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'bare name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'action_name',
                                    'lhs' => 'action name',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'reserved action name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_item',
                                    'lhs' => 'adverb item',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'action'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_item',
                                    'lhs' => 'adverb item',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'blessing'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_item',
                                    'lhs' => 'adverb item',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'group association'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_item',
                                    'lhs' => 'adverb item',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'left association'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_item',
                                    'lhs' => 'adverb item',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'proper specification'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_item',
                                    'lhs' => 'adverb item',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'right association'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_item',
                                    'lhs' => 'adverb item',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'separator specification'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'adverb_list',
                                    'lhs' => 'adverb list',
                                    'min' => 0,
                                    'rhs' => [
                                               'adverb item'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'alternative',
                                    'lhs' => 'alternative',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               'rhs',
                                               'adverb list'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'alternatives',
                                    'lhs' => 'alternatives',
                                    'min' => 1,
                                    'proper' => '1',
                                    'rhs' => [
                                               'alternative'
                                             ],
                                    'separator' => 'op equal priority'
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'blessing',
                                    'lhs' => 'blessing',
                                    'mask' => [
                                                0,
                                                0,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-22]',
                                               '[Lex-23]',
                                               'blessing name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'blessing_name',
                                    'lhs' => 'blessing name',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'reserved blessing name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'blessing_name',
                                    'lhs' => 'blessing name',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'standard name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'default_rule',
                                    'lhs' => 'default rule',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-2]',
                                               'op declare bnf',
                                               'adverb list'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'discard_rule',
                                    'lhs' => 'discard rule',
                                    'mask' => [
                                                0,
                                                0,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-6]',
                                               'op declare match',
                                               'single symbol'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'empty_rule',
                                    'lhs' => 'empty rule',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               'lhs',
                                               'op declare',
                                               'adverb list'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'group_association',
                                    'lhs' => 'group association',
                                    'mask' => [
                                                0,
                                                0,
                                                0
                                              ],
                                    'rhs' => [
                                               '[Lex-15]',
                                               '[Lex-16]',
                                               '[Lex-17]'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'left_association',
                                    'lhs' => 'left association',
                                    'mask' => [
                                                0,
                                                0,
                                                0
                                              ],
                                    'rhs' => [
                                               '[Lex-9]',
                                               '[Lex-10]',
                                               '[Lex-11]'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'lexeme_default_statement',
                                    'lhs' => 'lexeme default statement',
                                    'mask' => [
                                                0,
                                                0,
                                                0,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-3]',
                                               '[Lex-4]',
                                               '[Lex-5]',
                                               'adverb list'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'lhs',
                                    'lhs' => 'lhs',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'symbol name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'op_declare',
                                    'lhs' => 'op declare',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'op declare bnf'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'op_declare',
                                    'lhs' => 'op declare',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'op declare match'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'parenthesized_rhs_primary_list',
                                    'lhs' => 'parenthesized rhs primary list',
                                    'mask' => [
                                                0,
                                                1,
                                                0
                                              ],
                                    'rhs' => [
                                               '[Lex-24]',
                                               'rhs primary list',
                                               '[Lex-25]'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'priorities',
                                    'lhs' => 'priorities',
                                    'min' => 1,
                                    'proper' => '1',
                                    'rhs' => [
                                               'alternatives'
                                             ],
                                    'separator' => 'op loosen'
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'priority_rule',
                                    'lhs' => 'priority rule',
                                    'mask' => [
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               'lhs',
                                               'op declare',
                                               'priorities'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'proper_specification',
                                    'lhs' => 'proper specification',
                                    'mask' => [
                                                0,
                                                0,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-20]',
                                               '[Lex-21]',
                                               'boolean'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'quantified_rule',
                                    'lhs' => 'quantified rule',
                                    'mask' => [
                                                1,
                                                1,
                                                1,
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               'lhs',
                                               'op declare',
                                               'single symbol',
                                               'quantifier',
                                               'adverb list'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'quantifier',
                                    'lhs' => 'quantifier',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-26]'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'quantifier',
                                    'lhs' => 'quantifier',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-27]'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'rhs',
                                    'lhs' => 'rhs',
                                    'min' => 1,
                                    'rhs' => [
                                               'rhs primary'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'rhs_primary',
                                    'lhs' => 'rhs primary',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'parenthesized rhs primary list'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'rhs_primary',
                                    'lhs' => 'rhs primary',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'single quoted string'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'rhs_primary',
                                    'lhs' => 'rhs primary',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'single symbol'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'rhs_primary_list',
                                    'lhs' => 'rhs primary list',
                                    'min' => 1,
                                    'rhs' => [
                                               'rhs primary'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'right_association',
                                    'lhs' => 'right association',
                                    'mask' => [
                                                0,
                                                0,
                                                0
                                              ],
                                    'rhs' => [
                                               '[Lex-12]',
                                               '[Lex-13]',
                                               '[Lex-14]'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'separator_specification',
                                    'lhs' => 'separator specification',
                                    'mask' => [
                                                0,
                                                0,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-18]',
                                               '[Lex-19]',
                                               'single symbol'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'single_symbol',
                                    'lhs' => 'single symbol',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'character class'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'single_symbol',
                                    'lhs' => 'single symbol',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'symbol'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'start_rule',
                                    'lhs' => 'start rule',
                                    'mask' => [
                                                0,
                                                0,
                                                1
                                              ],
                                    'rhs' => [
                                               '[Lex-1]',
                                               'op declare bnf',
                                               'symbol'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement',
                                    'lhs' => 'statement',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'statement body'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement',
                                    'lhs' => 'statement',
                                    'mask' => [
                                                1,
                                                1
                                              ],
                                    'rhs' => [
                                               'statement body',
                                               '[Lex-0]'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement_body',
                                    'lhs' => 'statement body',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'default rule'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement_body',
                                    'lhs' => 'statement body',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'discard rule'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement_body',
                                    'lhs' => 'statement body',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'empty rule'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement_body',
                                    'lhs' => 'statement body',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'lexeme default statement'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement_body',
                                    'lhs' => 'statement body',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'priority rule'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement_body',
                                    'lhs' => 'statement body',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'quantified rule'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statement_body',
                                    'lhs' => 'statement body',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'start rule'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'statements',
                                    'lhs' => 'statements',
                                    'min' => 1,
                                    'rhs' => [
                                               'statement'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'symbol',
                                    'lhs' => 'symbol',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'symbol name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'symbol_name',
                                    'lhs' => 'symbol name',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'bare name'
                                             ]
                                  },
                                  {
                                    'action' => '[range,values]',
                                    'bless' => 'symbol_name',
                                    'lhs' => 'symbol name',
                                    'mask' => [
                                                1
                                              ],
                                    'rhs' => [
                                               'bracketed name'
                                             ]
                                  }
                                ],
                  'g1_symbols' => {
                                    'array descriptor' => {
                                                            'bless' => 'array_descriptor',
                                                            'semantics' => '[range,value]'
                                                          },
                                    'bare name' => {
                                                     'bless' => 'bare_name',
                                                     'semantics' => '[range,value]'
                                                   },
                                    'boolean' => {
                                                   'bless' => 'boolean',
                                                   'semantics' => '[range,value]'
                                                 },
                                    'bracketed name' => {
                                                          'bless' => 'bracketed_name',
                                                          'semantics' => '[range,value]'
                                                        },
                                    'character class' => {
                                                           'bless' => 'character_class',
                                                           'semantics' => '[range,value]'
                                                         },
                                    'op declare bnf' => {
                                                          'bless' => 'op_declare_bnf',
                                                          'semantics' => '[range,value]'
                                                        },
                                    'op declare match' => {
                                                            'bless' => 'op_declare_match',
                                                            'semantics' => '[range,value]'
                                                          },
                                    'op equal priority' => {
                                                             'bless' => 'op_equal_priority',
                                                             'semantics' => '[range,value]'
                                                           },
                                    'op loosen' => {
                                                     'bless' => 'op_loosen',
                                                     'semantics' => '[range,value]'
                                                   },
                                    'reserved action name' => {
                                                                'bless' => 'reserved_action_name',
                                                                'semantics' => '[range,value]'
                                                              },
                                    'reserved blessing name' => {
                                                                  'bless' => 'reserved_blessing_name',
                                                                  'semantics' => '[range,value]'
                                                                },
                                    'single quoted string' => {
                                                                'bless' => 'single_quoted_string',
                                                                'semantics' => '[range,value]'
                                                              },
                                    'standard name' => {
                                                         'bless' => 'standard_name',
                                                         'semantics' => '[range,value]'
                                                       }
                                  },
                  'is_lexeme' => {
                                   '[:discard]' => 1,
                                   '[Lex-0]' => 1,
                                   '[Lex-10]' => 1,
                                   '[Lex-11]' => 1,
                                   '[Lex-12]' => 1,
                                   '[Lex-13]' => 1,
                                   '[Lex-14]' => 1,
                                   '[Lex-15]' => 1,
                                   '[Lex-16]' => 1,
                                   '[Lex-17]' => 1,
                                   '[Lex-18]' => 1,
                                   '[Lex-19]' => 1,
                                   '[Lex-1]' => 1,
                                   '[Lex-20]' => 1,
                                   '[Lex-21]' => 1,
                                   '[Lex-22]' => 1,
                                   '[Lex-23]' => 1,
                                   '[Lex-24]' => 1,
                                   '[Lex-25]' => 1,
                                   '[Lex-26]' => 1,
                                   '[Lex-27]' => 1,
                                   '[Lex-2]' => 1,
                                   '[Lex-3]' => 1,
                                   '[Lex-4]' => 1,
                                   '[Lex-5]' => 1,
                                   '[Lex-6]' => 1,
                                   '[Lex-7]' => 1,
                                   '[Lex-8]' => 1,
                                   '[Lex-9]' => 1,
                                   'array descriptor' => 1,
                                   'bare name' => 1,
                                   'boolean' => 1,
                                   'bracketed name' => 1,
                                   'character class' => 1,
                                   'op declare bnf' => 1,
                                   'op declare match' => 1,
                                   'op equal priority' => 1,
                                   'op loosen' => 1,
                                   'reserved action name' => 1,
                                   'reserved blessing name' => 1,
                                   'single quoted string' => 1,
                                   'standard name' => 1
                                 }
                };
## The code before this line was automatically generated by sl_to_hash.pl

##use critic

    return $hashed_metag;

} ## end sub meta_grammar

1;

# vim: expandtab shiftwidth=4:
